@@ -9,10 +9,16 @@ def test():
     check("", "")
     check("\u0000\u0001\t\n\u001f ~\u007f", "\u0000\u0001\t\n\u001f ~\u007f")
     check("sample", "sample")
-    check("\ue000", "")
-    check("\ufdff", "")
+
     check("\u0080", "")
     check("\u00ff", "y")
+    check("\ue000", "")
+    check("\ufdff", "")
+    check("\U000e0020", " ")
+    check("\U000e007e", "~")
+    check("\U000f0000", "")
+    check("\U000f0001", "")
+    check("\U0010ffff", "")
 
     check("René François Lacôte", "Rene Francois Lacote")
     check("Blöße", "Blosse")
